; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1
;==============================================================================
;-| AIZbg |-----------------------------------------------------------------
[Command]
name = "AI0"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI1"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI2"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI3"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI4"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI5"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI6"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI7"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI8"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI9"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI10"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI11"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI12"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI13"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI14"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI15"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI16"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI17"
command = a,B,c,x,y,z,s,B,D,F,U,a,b,c,x,y,z,s,s
time = 0
[Command]
name = "AI18"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI19"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI20"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI21"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI22"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI23"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
;-| Super Motions |--------------------------------------------------------

;-| Special Motions |------------------------------------------------------
[Command]
name = "Super Fire Ball"
command = D,DF,F,D,DF,F,a
time = 30

[Command]
name = "Super Fire Ball"
command = D,DF,F,D,DF,F,b
time = 30

[Command]
name = "Super Fire Ball"
command = D,DF,F,D,DF,F,c
time = 30

[Command]
name = "Super Egg Throw"
command = D,DF,F,D,DF,F,x
time = 30

[Command]
name = "Super Egg Throw"
command = D,DF,F,D,DF,F,y
time = 30

[Command]
name = "Super Egg Throw"
command = D,DF,F,D,DF,F,z
time = 30

[Command]
name = "YoshiCharge"
command = B,F,z
time = 15

[Command]
name = "YoshiCharge"
command = B,F,y
time = 15

[Command]
name = "YoshiCharge"
command = B,F,x
time = 15

[Command]
name = "YoshiCharge"
command = B,F,a
time = 15

[Command]
name = "YoshiCharge"
command = B,F,b
time = 15

[Command]
name = "YoshiCharge"
command = B,F,c
time = 15

[Command]
name = "Yoshi Stampede"
command = B,F,a+x
time = 30

[Command]
name = "H Fire Breath"
command = D,DF,F,y+b
time = 30

[Command]
name = "throw3" ;Required (do not remove)
command = b+z
time = 1

[Command]
name = "throw2" ;Required (do not remove)
command = b+y
time = 1

[Command]
name = "throw1" ;Required (do not remove)
command = b+x
time = 1
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------

[Command]
name = "B,B_C"
command = B,B,c
time = 15

[Command]
name = "F,F_A+B"
command = F,F,a+b


[Command]
name = "F,F_C"
command = F,F,c


[Command]
name = "F,F_B"
command = F,F,b


[Command]
name = "F,F_A"
command = F,F,a


[Command]
name = "D,D_C"
command = D,D,c


[Command]
name = "D,D_B"
command = D,D,b


[Command]
name = "D,D_A"
command = D,D,a


[Command]
name = "B,F_A"
command = B,F,a


[Command]
name = "QCF_X+Y"
command = D,DF,F,x+y


[Command]
name = "QCF_A+B"
command = D,DF,F,a+b


[Command]
name = "QCF_Z"
command = D,DF,F,z


[Command]
name = "QCF_Y"
command = D,DF,F,y


[Command]
name = "QCF_X"
command = D,DF,F,x


[Command]
name = "QCF_C"
command = D,DF,F,c


[Command]
name = "QCF_B"
command = D,DF,F,b


[Command]
name = "QCF_A"
command = D,DF,F,a


[Command]
name = "QCB_A+B"
command = D,DB,B,a+b


[Command]
name = "QCB_X+Y"
command = D,DB,B,x+y


[Command]
name = "BF_B+Y"
command = B,F,b+y
time = 15

[Command]
name = "QCB_B+Y"
command = D,DB,B,b+y


[Command]
name = "QCB_Z"
command = D,DB,B,z


[Command]
name = "QCB_Y"
command = D,DB,B,y


[Command]
name = "QCB_X"
command = D,DB,B,x


[Command]
name = "QCB_C"
command = D,DB,B,c


[Command]
name = "QCB_B"
command = D,DB,B,b


[Command]
name = "QCB_A"
command = D,DB,B,a


[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "All Punch"
command = x+y+z
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

[Command]
name = "B,F,b+x"
command = B,F,b+x

[Command]
name = "B,F,b+y"
command = B,F,b+y

[Command]
name = "B,F,b+z"
command = B,F,b+z

[Command]
name = "B,F,a+b+y"
command = B,F,a+b+y
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = ctrl
trigger2 = movecontact = 1
var(1) = 1
;==========================================================================
;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = Var(59) = 0
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = Var(59) = 0
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = Var(59) = 0
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
; Yoshi Stampede
[State -1, Yoshi Stampede]
type = ChangeState
value = 3050
triggerall = Var(59) = 0
triggerall = command = "Yoshi Stampede"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
triggerall = numproj < 1
triggerall = power >= 3000
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Hyper Fire Breath
[State -1, Hyper Fire Breath]
type = ChangeState
value = 3000
triggerall = Var(59) = 0
triggerall = command = "H Fire Breath"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
triggerall = numproj < 1
triggerall = power >= 3000
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Egg Bounce EX
[State -1, Egg Bounce EX]
type = ChangeState
value = 1097
triggerall = Var(59) = 0
triggerall = command = "B,F,a+b+y"
triggerall = command != "holddown"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 1020) && time > 4
;---------------------------------------------------------------------------
; Egg Bounce C
[State -1, Egg Bounce C]
type = ChangeState
value = 1096
triggerall = Var(59) = 0
triggerall = command = "B,F,b+z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 1020) && time > 4
;---------------------------------------------------------------------------
; Egg Bounce B
[State -1, Egg Bounce B]
type = ChangeState
value = 1095
triggerall = Var(59) = 0
triggerall = command = "B,F,b+y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 1020) && time > 4
;---------------------------------------------------------------------------
; Egg Bounce A
[State -1, Egg Bounce A]
type = ChangeState
value = 1094
triggerall = Var(59) = 0
triggerall = command = "B,F,b+x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 1020) && time > 4
;---------------------------------------------------------------------------
; Throw
[State -1, Throw3]
type = ChangeState
value = 802
triggerall = Var(59) = 0
triggerall = command = "throw3"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Throw
[State -1, Throw2]
type = ChangeState
value = 801
triggerall = Var(59) = 0
triggerall = command = "throw2"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Throw
[State -1, Throw1]
type = ChangeState
value = 800
triggerall = Var(59) = 0
triggerall = command = "throw1"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Air Super Egg Throw
[State -1, Air Super Egg Throw]
type = ChangeState
value = 2003
triggerall = Var(59) = 0
triggerall = command = "Super Egg Throw"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 2000
;---------------------------------------------------------------------------
; Stand Super Fire Ball
[State -1, Stand Super Egg Throw]
type = ChangeState
value = 2002
triggerall = Var(59) = 0
triggerall = command = "Super Egg Throw"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 2000
;---------------------------------------------------------------------------
; Air Super Fire Ball
[State -1, Air Super Fire Ball]
type = ChangeState
value = 2001
triggerall = Var(59) = 0
triggerall = command = "Super Fire Ball"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 2000
;---------------------------------------------------------------------------
; Stand Super Fire Ball
[State -1, Stand Super Fire Ball]
type = ChangeState
value = 2000
triggerall = Var(59) = 0
triggerall = command = "Super Fire Ball"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 2000
;---------------------------------------------------------------------------
; Earthquake Stomp
[State -1, Earthquake Stomp]
type = ChangeState
value = 1055
triggerall = Var(59) = 0
triggerall = command = "D,D_C"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1025
trigger2 = time >= 14
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Ground Pound
[State -1, Ground Pound]
type = ChangeState
value = 1051
triggerall = Var(59) = 0
triggerall = command = "D,D_B"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1025
trigger2 = time >= 14
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Flutter Kick
[State -1, Flutter Kick]
type = ChangeState
value = 1050
triggerall = Var(59) = 0
triggerall = command = "D,D_A"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1025
trigger2 = time >= 14
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; ParaYoshi Charge
[State -1, ParaYoshi Charge]
type = ChangeState
value = 1025
triggerall = Var(59) = 0
triggerall = command = "FF"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 610
trigger2 = time >= 2
trigger3 = stateno = 600
trigger3 = time >= 2
trigger4 = stateno = 630
trigger4 = time >= 2
trigger5 = stateno = 640
trigger5 = time >= 2
trigger6 = stateno = 620
trigger6 = time >= 2
trigger7 = stateno = 650
trigger7 = time >= 2
;---------------------------------------------------------------------------
; Yoshi Charge
[State -1, Yoshi Charge]
type = ChangeState
value = 1020
triggerall = Var(59) = 0
triggerall = command = "YoshiCharge"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2

;---------------------------------------------------------------------------
; Egg Roll EX
[State -1, Egg Roll EX]
type = ChangeState
value = 1027
triggerall = Var(59) = 0
triggerall = command = "F,F_A+B"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = power >= 500
;---------------------------------------------------------------------------
; Forward Egg Dodge
[State -1, Forward Egg Dodge]
type = ChangeState
value = 1023
triggerall = Var(59) = 0
triggerall = command = "F,F_C"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Egg Roll B
[State -1, Egg Roll B]
type = ChangeState
value = 1022
triggerall = Var(59) = 0
triggerall = command = "F,F_B"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 1020) && time > 4
;---------------------------------------------------------------------------
; Egg Roll A
[State -1, Egg Roll A]
type = ChangeState
value = 1021
triggerall = Var(59) = 0
triggerall = command = "F,F_A"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 1020) && time > 4
;---------------------------------------------------------------------------
; SSBM Headbutt - EX
[State -1, SSBM Headbutt - EX]
type = ChangeState
value = 1083
triggerall = Var(59) = 0
triggerall = command = "QCB_X+Y"
triggerall = command != "holddown"
triggerall = power >= 500
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;---------------------------------------------------------------------------
; SSBM Headbutt - 3
[State -1, SSBM Headbutt - 3]
type = ChangeState
value = 1082
triggerall = Var(59) = 0
triggerall = command = "QCB_Z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;---------------------------------------------------------------------------
; SSBM Headbutt - 2
[State -1, SSBM Headbutt - 2]
type = ChangeState
value = 1081
triggerall = Var(59) = 0
triggerall = command = "QCB_Y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;---------------------------------------------------------------------------
; SSBM Headbutt - 1
[State -1, SSBM Headbutt - 1]
type = ChangeState
value = 1080
triggerall = Var(59) = 0
triggerall = command = "QCB_X"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Air Egg Throw EX
[State -1, Air Egg Throw EX]
type = ChangeState
value = 1031
triggerall = Var(59) = 0
triggerall = command = "QCF_X+Y"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 500
;---------------------------------------------------------------------------
; Air Egg Throw Y
[State -1, Air Egg Throw Y]
type = ChangeState
value = 1019
triggerall = Var(59) = 0
triggerall = command = "QCF_Z"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
;---------------------------------------------------------------------------
; Air Egg Throw Y
[State -1, Air Egg Throw Y]
type = ChangeState
value = 1018
triggerall = Var(59) = 0
triggerall = command = "QCF_Y"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
;---------------------------------------------------------------------------
; Air Egg Throw X
[State -1, Air Egg Throw X]
type = ChangeState
value = 1017
triggerall = Var(59) = 0
triggerall = command = "QCF_X"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
;---------------------------------------------------------------------------
; Stand Egg Throw EX
[State -1, Stand Egg Throw EX]
type = ChangeState
value = 1030
triggerall = Var(59) = 0
triggerall = command = "QCF_X+Y"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 500
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Egg Throw Z
[State -1, Stand Egg Throw Z]
type = ChangeState
value = 1016
triggerall = Var(59) = 0
triggerall = command = "QCF_Z"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Egg Throw Y
[State -1, Stand Egg Throw Y]
type = ChangeState
value = 1015
triggerall = Var(59) = 0
triggerall = command = "QCF_Y"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Egg Throw X
[State -1, Stand Egg Throw X]
type = ChangeState
value = 1010
triggerall = Var(59) = 0
triggerall = command = "QCF_X"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;--------------------------------------------------------------------------
; Stand DS Fire Breath EX
[State -1, Stand DS Fire Breath EX]
type = ChangeState
value = 1073
triggerall = Var(59) = 0
triggerall = command = "QCB_A+B"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 500
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;--------------------------------------------------------------------------
; Stand DS Fire Breath C
[State -1, Stand DS Fire Breath C]
type = ChangeState
value = 1072
triggerall = Var(59) = 0
triggerall = command = "QCB_C"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;--------------------------------------------------------------------------
; Stand DS Fire Breath B
[State -1, Stand DS Fire Breath B]
type = ChangeState
value = 1071
triggerall = Var(59) = 0
triggerall = command = "QCB_B"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;--------------------------------------------------------------------------
; Stand DS Fire Breath A
[State -1, Stand DS Fire Breath A]
type = ChangeState
value = 1070
triggerall = Var(59) = 0
triggerall = command = "QCB_A"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = stateno = 210
trigger2 = time >= 2
trigger3 = stateno = 200
trigger3 = time >= 2
trigger4 = stateno = 230
trigger4 = time >= 2
trigger5 = stateno = 240
trigger5 = time >= 2
trigger6 = stateno = 220
trigger6 = time >= 2
trigger7 = stateno = 250
trigger7 = time >= 2
;---------------------------------------------------------------------------
; Air EX Fire Breath
[State -1, Air EX Fire Breath]
type = ChangeState
value = 1008
triggerall = Var(59) = 0
triggerall = command = "QCF_A+B"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 500
;---------------------------------------------------------------------------
; Air Fire Breath C
[State -1, Air Fire Breath C]
type = ChangeState
value = 1005
triggerall = Var(59) = 0
triggerall = command = "QCF_C"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
;---------------------------------------------------------------------------
; Air Fire Breath B
[State -1, Air Fire Breath B]
type = ChangeState
value = 1004
triggerall = Var(59) = 0
triggerall = command = "QCF_B"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
;---------------------------------------------------------------------------
; Air Fire Breath A
[State -1, Air Fire Breath A]
type = ChangeState
value = 1003
triggerall = Var(59) = 0
triggerall = command = "QCF_A"
triggerall = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
;---------------------------------------------------------------------------
; Stand EX Fire Breath
[State -1, Stand EX Fire Breath]
type = ChangeState
value = 1007
triggerall = Var(59) = 0
triggerall = command = "QCF_A+B"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
triggerall = power >= 500
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Fire Breath C
[State -1, Stand Fire Breath C]
type = ChangeState
value = 1002
triggerall = Var(59) = 0
triggerall = command = "QCF_C"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Fire Breath B
[State -1, Stand Fire Breath B]
type = ChangeState
value = 1001
triggerall = Var(59) = 0
triggerall = command = "QCF_B"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Fire Breath A
[State -1, Stand Fire Breath A]
type = ChangeState
value = 1000
triggerall = Var(59) = 0
triggerall = command = "QCF_A"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger1 = var(1) = 1
triggerall = numproj < 1
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 220) && time > 2
trigger5 = (stateno = 230) && time > 2
trigger6 = (stateno = 240) && time > 2
trigger7 = (stateno = 250) && time > 2
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = Var(59) = 0
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time >= 2
;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = Var(59) = 0
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 230) && time > 2
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = Var(59) = 0
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 230) && time > 2
trigger5 = (stateno = 240) && time > 2
;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = Var(59) = 0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time >= 2
;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = Var(59) = 0
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 230) && time > 2
;---------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = Var(59) = 0
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 210) && time > 2
trigger4 = (stateno = 230) && time > 2
trigger5 = (stateno = 240) && time > 2
;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = Var(59) = 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = Var(59) = 0
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = Var(59) = 0
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 400
triggerall = Var(59) = 0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 410
triggerall = Var(59) = 0
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 420
triggerall = Var(59) = 0
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = Var(59) = 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = Var(59) = 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = Var(59) = 0
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 1025
trigger2 = time >= 5
;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = Var(59) = 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = Var(59) = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = Var(59) = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = var(1) = 1
trigger2 = stateno = 1025
trigger2 = time >= 5
;---------------------------------------------------------------------------
